ApiMultiPartBase class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
callApi(
String url, Map< String, String> ? body, List<File> ? files, String? fileParamName, {Map<String, String> ? headers, Map<String, dynamic> ? queryParameters, String? requestType, dynamic loading(bool loading)?}) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited